Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6428)

Unified Diff: chrome/browser/task_manager/task_manager.h

Issue 10790062: [Panels refactor] Track Panels in TaskManager now that they are not under the tab contents umbrella. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: feedback changes Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/prerender/prerender_browsertest.cc ('k') | chrome/browser/task_manager/task_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/task_manager/task_manager.h
diff --git a/chrome/browser/task_manager/task_manager.h b/chrome/browser/task_manager/task_manager.h
index 2fbca72b380bc8429ebe628eaac603764eb1597e..117ac60bf79f9fb9060704af36a093d8b0b0e389 100644
--- a/chrome/browser/task_manager/task_manager.h
+++ b/chrome/browser/task_manager/task_manager.h
@@ -20,13 +20,16 @@
#include "chrome/browser/renderer_host/web_cache_manager.h"
#include "third_party/WebKit/Source/WebKit/chromium/public/WebCache.h"
-class TabContents;
class TaskManagerModel;
namespace base {
class ProcessMetrics;
}
+namespace content {
+class WebContents;
+}
+
namespace extensions {
class Extension;
}
@@ -103,9 +106,10 @@ class TaskManager {
// Invokes or reveals developer tools window for this resource.
virtual void Inspect() const {}
- // A helper function for ActivateFocusedTab. Returns NULL by default
- // because not all resources have an associated tab.
- virtual TabContents* GetTabContents() const { return NULL; }
+ // A helper function for ActivateProcess when selected resource refers
+ // to a Tab or other window containing web contents. Returns NULL by
+ // default because not all resources have an associated web contents.
+ virtual content::WebContents* GetWebContents() const { return NULL; }
// Whether this resource does report the network usage accurately.
// This controls whether 0 or N/A is displayed when no bytes have been
@@ -401,8 +405,8 @@ class TaskManagerModel : public base::RefCountedThreadSafe<TaskManagerModel> {
// Returns the type of the given resource.
TaskManager::Resource::Type GetResourceType(int index) const;
- // Returns TabContents of given resource or NULL if not applicable.
- TabContents* GetResourceTabContents(int index) const;
+ // Returns WebContents of given resource or NULL if not applicable.
+ content::WebContents* GetResourceWebContents(int index) const;
// Returns Extension of given resource or NULL if not applicable.
const extensions::Extension* GetResourceExtension(int index) const;
« no previous file with comments | « chrome/browser/prerender/prerender_browsertest.cc ('k') | chrome/browser/task_manager/task_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698